====
v440
====

Overview
--------

mutable version objects in accordance with PEP440

Installation
------------

To install v440, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install v440

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/v440/#files>`_
* `Source <https://github.com/johannes-programming/v440>`_

Credits
-------

- Author: Johannes
- Email: johannes-programming@mailfence.com

Thank you for using v440!